@@ -2,7 +2,7 @@ testthat::context("Evaluate")
 
 testthat::test_that("", {
   e <- new.env(parent = environment())
-  fname <- system.file("Introduction.Rmd", package = "REPLesentR")
+  fname <- system.file("Introduction.plain", package = "REPLesentR")
   file.copy(fname, tfname <- tempfile(fileext = ".Rmd"))
   slideDeck <- SlideDeck()$new(Read()$auto(tfname, quiet = TRUE))
   evaluate <- Evaluate(e, quiet = TRUE)
